@@ -1,12 +1,8 @@
 import subprocess
 from subprocess import run
 
-try:
-    from picker.abstractionhelper import is_wayland, is_installed
-    from picker.typer import Typer
-except ModuleNotFoundError:
-    from abstractionhelper import is_wayland, is_installed
-    from typer import Typer
+from .abstractionhelper import is_wayland, is_installed
+from .typer import Typer
 
 
 class Clipboarder:
